# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/appengine_v1alpha/proto/version.proto

from cloudsdk.google.protobuf.internal import enum_type_wrapper
from cloudsdk.google.protobuf import descriptor as _descriptor
from cloudsdk.google.protobuf import message as _message
from cloudsdk.google.protobuf import reflection as _reflection
from cloudsdk.google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.cloud.appengine_v1alpha.proto import app_yaml_pb2 as google_dot_cloud_dot_appengine__v1alpha_dot_proto_dot_app__yaml__pb2
from google.cloud.appengine_v1alpha.proto import deploy_pb2 as google_dot_cloud_dot_appengine__v1alpha_dot_proto_dot_deploy__pb2
from cloudsdk.google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from cloudsdk.google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/cloud/appengine_v1alpha/proto/version.proto',
  package='google.appengine.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\034com.google.appengine.v1alphaB\014VersionProtoP\001ZAgoogle.golang.org/genproto/googleapis/appengine/v1alpha;appengine',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2google/cloud/appengine_v1alpha/proto/version.proto\x12\x18google.appengine.v1alpha\x1a\x33google/cloud/appengine_v1alpha/proto/app_yaml.proto\x1a\x31google/cloud/appengine_v1alpha/proto/deploy.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\"\xe6\x0f\n\x07Version\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12G\n\x11\x61utomatic_scaling\x18\x03 \x01(\x0b\x32*.google.appengine.v1alpha.AutomaticScalingH\x00\x12?\n\rbasic_scaling\x18\x04 \x01(\x0b\x32&.google.appengine.v1alpha.BasicScalingH\x00\x12\x41\n\x0emanual_scaling\x18\x05 \x01(\x0b\x32\'.google.appengine.v1alpha.ManualScalingH\x00\x12\x46\n\x10inbound_services\x18\x06 \x03(\x0e\x32,.google.appengine.v1alpha.InboundServiceType\x12\x16\n\x0einstance_class\x18\x07 \x01(\t\x12\x32\n\x07network\x18\x08 \x01(\x0b\x32!.google.appengine.v1alpha.Network\x12\r\n\x05zones\x18v \x03(\t\x12\x36\n\tresources\x18\t \x01(\x0b\x32#.google.appengine.v1alpha.Resources\x12\x0f\n\x07runtime\x18\n \x01(\t\x12\x17\n\x0fruntime_channel\x18u \x01(\t\x12\x12\n\nthreadsafe\x18\x0b \x01(\x08\x12\n\n\x02vm\x18\x0c \x01(\x08\x12J\n\rbeta_settings\x18\r \x03(\x0b\x32\x33.google.appengine.v1alpha.Version.BetaSettingsEntry\x12\x0b\n\x03\x65nv\x18\x0e \x01(\t\x12?\n\x0eserving_status\x18\x0f \x01(\x0e\x32\'.google.appengine.v1alpha.ServingStatus\x12\x12\n\ncreated_by\x18\x10 \x01(\t\x12/\n\x0b\x63reate_time\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10\x64isk_usage_bytes\x18\x12 \x01(\x03\x12\x1b\n\x13runtime_api_version\x18\x15 \x01(\t\x12$\n\x1cruntime_main_executable_path\x18\x16 \x01(\t\x12\x32\n\x08handlers\x18\x64 \x03(\x0b\x32 .google.appengine.v1alpha.UrlMap\x12>\n\x0e\x65rror_handlers\x18\x65 \x03(\x0b\x32&.google.appengine.v1alpha.ErrorHandler\x12\x34\n\tlibraries\x18\x66 \x03(\x0b\x32!.google.appengine.v1alpha.Library\x12>\n\napi_config\x18g \x01(\x0b\x32*.google.appengine.v1alpha.ApiConfigHandler\x12J\n\renv_variables\x18h \x03(\x0b\x32\x33.google.appengine.v1alpha.Version.EnvVariablesEntry\x12\x35\n\x12\x64\x65\x66\x61ult_expiration\x18i \x01(\x0b\x32\x19.google.protobuf.Duration\x12;\n\x0chealth_check\x18j \x01(\x0b\x32%.google.appengine.v1alpha.HealthCheck\x12\x41\n\x0freadiness_check\x18p \x01(\x0b\x32(.google.appengine.v1alpha.ReadinessCheck\x12?\n\x0eliveness_check\x18q \x01(\x0b\x32\'.google.appengine.v1alpha.LivenessCheck\x12\x1b\n\x13nobuild_files_regex\x18k \x01(\t\x12\x38\n\ndeployment\x18l \x01(\x0b\x32$.google.appengine.v1alpha.Deployment\x12\x13\n\x0bversion_url\x18m \x01(\t\x12L\n\x15\x65ndpoints_api_service\x18n \x01(\x0b\x32-.google.appengine.v1alpha.EndpointsApiService\x12\x42\n\tlifecycle\x18s \x01(\x0e\x32/.google.appengine.v1alpha.Version.LifecycleType\x12\x38\n\nentrypoint\x18z \x01(\x0b\x32$.google.appengine.v1alpha.Entrypoint\x12@\n\x0einstance_stats\x18\xac\x02 \x01(\x0b\x32\'.google.appengine.v1alpha.InstanceStats\x12J\n\x14vpc_access_connector\x18y \x01(\x0b\x32,.google.appengine.v1alpha.VpcAccessConnector\x1a\x33\n\x11\x42\x65taSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11\x45nvVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"*\n\rLifecycleType\x12\n\n\x06NORMAL\x10\x00\x12\r\n\tEPHEMERAL\x10\x01\x42\t\n\x07scaling\"E\n\rInstanceStats\x12\x15\n\rnum_instances\x18\x01 \x01(\x03\x12\x1d\n\x15num_healthy_instances\x18\x02 \x01(\x03\"\xfc\x01\n\x13\x45ndpointsApiService\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tconfig_id\x18\x02 \x01(\t\x12W\n\x10rollout_strategy\x18\x03 \x01(\x0e\x32=.google.appengine.v1alpha.EndpointsApiService.RolloutStrategy\x12\x1e\n\x16\x64isable_trace_sampling\x18\x04 \x01(\x08\"K\n\x0fRolloutStrategy\x12 \n\x1cUNSPECIFIED_ROLLOUT_STRATEGY\x10\x00\x12\t\n\x05\x46IXED\x10\x01\x12\x0b\n\x07MANAGED\x10\x02\"\x82\x06\n\x10\x41utomaticScaling\x12\x33\n\x10\x63ool_down_period\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x41\n\x0f\x63pu_utilization\x18\x02 \x01(\x0b\x32(.google.appengine.v1alpha.CpuUtilization\x12\x1f\n\x17max_concurrent_requests\x18\x03 \x01(\x05\x12\x1a\n\x12max_idle_instances\x18\x04 \x01(\x05\x12\x1b\n\x13max_total_instances\x18\x05 \x01(\x05\x12\x36\n\x13max_pending_latency\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1a\n\x12min_idle_instances\x18\x07 \x01(\x05\x12\x1b\n\x13min_total_instances\x18\x08 \x01(\x05\x12\x36\n\x13min_pending_latency\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\x12I\n\x13request_utilization\x18\n \x01(\x0b\x32,.google.appengine.v1alpha.RequestUtilization\x12\x43\n\x10\x64isk_utilization\x18\x0b \x01(\x0b\x32).google.appengine.v1alpha.DiskUtilization\x12I\n\x13network_utilization\x18\x0c \x01(\x0b\x32,.google.appengine.v1alpha.NetworkUtilization\x12>\n\x0e\x63ustom_metrics\x18\x15 \x03(\x0b\x32&.google.appengine.v1alpha.CustomMetric\x12X\n\x1bstandard_scheduler_settings\x18\x14 \x01(\x0b\x32\x33.google.appengine.v1alpha.StandardSchedulerSettings\"V\n\x0c\x42\x61sicScaling\x12/\n\x0cidle_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x15\n\rmax_instances\x18\x02 \x01(\x05\"\"\n\rManualScaling\x12\x11\n\tinstances\x18\x01 \x01(\x05\"j\n\x0e\x43puUtilization\x12<\n\x19\x61ggregation_window_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1a\n\x12target_utilization\x18\x02 \x01(\x01\"a\n\x12RequestUtilization\x12\'\n\x1ftarget_request_count_per_second\x18\x01 \x01(\x05\x12\"\n\x1atarget_concurrent_requests\x18\x02 \x01(\x05\"\xa7\x01\n\x0f\x44iskUtilization\x12%\n\x1dtarget_write_bytes_per_second\x18\x0e \x01(\x05\x12#\n\x1btarget_write_ops_per_second\x18\x0f \x01(\x05\x12$\n\x1ctarget_read_bytes_per_second\x18\x10 \x01(\x05\x12\"\n\x1atarget_read_ops_per_second\x18\x11 \x01(\x05\"\xb8\x01\n\x12NetworkUtilization\x12$\n\x1ctarget_sent_bytes_per_second\x18\x01 \x01(\x05\x12&\n\x1etarget_sent_packets_per_second\x18\x0b \x01(\x05\x12(\n target_received_bytes_per_second\x18\x0c \x01(\x05\x12*\n\"target_received_packets_per_second\x18\r \x01(\x05\"\x9b\x01\n\x0c\x43ustomMetric\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\x12\x13\n\x0btarget_type\x18\x02 \x01(\t\x12\x1c\n\x12target_utilization\x18\x03 \x01(\x01H\x00\x12$\n\x1asingle_instance_assignment\x18\x04 \x01(\x01H\x00\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\tB\r\n\x0btarget_spec\"\x90\x01\n\x19StandardSchedulerSettings\x12\x1e\n\x16target_cpu_utilization\x18\x01 \x01(\x01\x12%\n\x1dtarget_throughput_utilization\x18\x02 \x01(\x01\x12\x15\n\rmin_instances\x18\x03 \x01(\x05\x12\x15\n\rmax_instances\x18\x04 \x01(\x05\"y\n\x07Network\x12\x17\n\x0f\x66orwarded_ports\x18\x01 \x03(\t\x12\x14\n\x0cinstance_tag\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x17\n\x0fsubnetwork_name\x18\x04 \x01(\t\x12\x18\n\x10session_affinity\x18\x05 \x01(\x08\"<\n\x06Volume\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bvolume_type\x18\x02 \x01(\t\x12\x0f\n\x07size_gb\x18\x03 \x01(\x01\"o\n\tResources\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x01\x12\x0f\n\x07\x64isk_gb\x18\x02 \x01(\x01\x12\x11\n\tmemory_gb\x18\x03 \x01(\x01\x12\x31\n\x07volumes\x18\x04 \x03(\x0b\x32 .google.appengine.v1alpha.Volume\"\"\n\x12VpcAccessConnector\x12\x0c\n\x04name\x18\x01 \x01(\t\"(\n\nEntrypoint\x12\x0f\n\x05shell\x18\x01 \x01(\tH\x00\x42\t\n\x07\x63ommand*\xbb\x02\n\x12InboundServiceType\x12\x1f\n\x1bINBOUND_SERVICE_UNSPECIFIED\x10\x00\x12\x18\n\x14INBOUND_SERVICE_MAIL\x10\x01\x12\x1f\n\x1bINBOUND_SERVICE_MAIL_BOUNCE\x10\x02\x12\x1e\n\x1aINBOUND_SERVICE_XMPP_ERROR\x10\x03\x12 \n\x1cINBOUND_SERVICE_XMPP_MESSAGE\x10\x04\x12\"\n\x1eINBOUND_SERVICE_XMPP_SUBSCRIBE\x10\x05\x12!\n\x1dINBOUND_SERVICE_XMPP_PRESENCE\x10\x06\x12$\n INBOUND_SERVICE_CHANNEL_PRESENCE\x10\x07\x12\x1a\n\x16INBOUND_SERVICE_WARMUP\x10\t*I\n\rServingStatus\x12\x1e\n\x1aSERVING_STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07SERVING\x10\x01\x12\x0b\n\x07STOPPED\x10\x02\x42q\n\x1c\x63om.google.appengine.v1alphaB\x0cVersionProtoP\x01ZAgoogle.golang.org/genproto/googleapis/appengine/v1alpha;appengineb\x06proto3'
  ,
  dependencies=[google_dot_cloud_dot_appengine__v1alpha_dot_proto_dot_app__yaml__pb2.DESCRIPTOR,google_dot_cloud_dot_appengine__v1alpha_dot_proto_dot_deploy__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])

_INBOUNDSERVICETYPE = _descriptor.EnumDescriptor(
  name='InboundServiceType',
  full_name='google.appengine.v1alpha.InboundServiceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INBOUND_SERVICE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INBOUND_SERVICE_MAIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INBOUND_SERVICE_MAIL_BOUNCE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INBOUND_SERVICE_XMPP_ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INBOUND_SERVICE_XMPP_MESSAGE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INBOUND_SERVICE_XMPP_SUBSCRIBE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INBOUND_SERVICE_XMPP_PRESENCE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INBOUND_SERVICE_CHANNEL_PRESENCE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INBOUND_SERVICE_WARMUP', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4773,
  serialized_end=5088,
)
_sym_db.RegisterEnumDescriptor(_INBOUNDSERVICETYPE)

InboundServiceType = enum_type_wrapper.EnumTypeWrapper(_INBOUNDSERVICETYPE)
_SERVINGSTATUS = _descriptor.EnumDescriptor(
  name='ServingStatus',
  full_name='google.appengine.v1alpha.ServingStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SERVING_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5090,
  serialized_end=5163,
)
_sym_db.RegisterEnumDescriptor(_SERVINGSTATUS)

ServingStatus = enum_type_wrapper.EnumTypeWrapper(_SERVINGSTATUS)
INBOUND_SERVICE_UNSPECIFIED = 0
INBOUND_SERVICE_MAIL = 1
INBOUND_SERVICE_MAIL_BOUNCE = 2
INBOUND_SERVICE_XMPP_ERROR = 3
INBOUND_SERVICE_XMPP_MESSAGE = 4
INBOUND_SERVICE_XMPP_SUBSCRIBE = 5
INBOUND_SERVICE_XMPP_PRESENCE = 6
INBOUND_SERVICE_CHANNEL_PRESENCE = 7
INBOUND_SERVICE_WARMUP = 9
SERVING_STATUS_UNSPECIFIED = 0
SERVING = 1
STOPPED = 2


_VERSION_LIFECYCLETYPE = _descriptor.EnumDescriptor(
  name='LifecycleType',
  full_name='google.appengine.v1alpha.Version.LifecycleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPHEMERAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2249,
  serialized_end=2291,
)
_sym_db.RegisterEnumDescriptor(_VERSION_LIFECYCLETYPE)

_ENDPOINTSAPISERVICE_ROLLOUTSTRATEGY = _descriptor.EnumDescriptor(
  name='RolloutStrategy',
  full_name='google.appengine.v1alpha.EndpointsApiService.RolloutStrategy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_ROLLOUT_STRATEGY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIXED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2553,
  serialized_end=2628,
)
_sym_db.RegisterEnumDescriptor(_ENDPOINTSAPISERVICE_ROLLOUTSTRATEGY)


_VERSION_BETASETTINGSENTRY = _descriptor.Descriptor(
  name='BetaSettingsEntry',
  full_name='google.appengine.v1alpha.Version.BetaSettingsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.appengine.v1alpha.Version.BetaSettingsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.appengine.v1alpha.Version.BetaSettingsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2143,
  serialized_end=2194,
)

_VERSION_ENVVARIABLESENTRY = _descriptor.Descriptor(
  name='EnvVariablesEntry',
  full_name='google.appengine.v1alpha.Version.EnvVariablesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.appengine.v1alpha.Version.EnvVariablesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.appengine.v1alpha.Version.EnvVariablesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2196,
  serialized_end=2247,
)

_VERSION = _descriptor.Descriptor(
  name='Version',
  full_name='google.appengine.v1alpha.Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.appengine.v1alpha.Version.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.appengine.v1alpha.Version.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automatic_scaling', full_name='google.appengine.v1alpha.Version.automatic_scaling', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basic_scaling', full_name='google.appengine.v1alpha.Version.basic_scaling', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manual_scaling', full_name='google.appengine.v1alpha.Version.manual_scaling', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inbound_services', full_name='google.appengine.v1alpha.Version.inbound_services', index=5,
      number=6, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_class', full_name='google.appengine.v1alpha.Version.instance_class', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network', full_name='google.appengine.v1alpha.Version.network', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zones', full_name='google.appengine.v1alpha.Version.zones', index=8,
      number=118, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='google.appengine.v1alpha.Version.resources', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime', full_name='google.appengine.v1alpha.Version.runtime', index=10,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_channel', full_name='google.appengine.v1alpha.Version.runtime_channel', index=11,
      number=117, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threadsafe', full_name='google.appengine.v1alpha.Version.threadsafe', index=12,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vm', full_name='google.appengine.v1alpha.Version.vm', index=13,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beta_settings', full_name='google.appengine.v1alpha.Version.beta_settings', index=14,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env', full_name='google.appengine.v1alpha.Version.env', index=15,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serving_status', full_name='google.appengine.v1alpha.Version.serving_status', index=16,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='google.appengine.v1alpha.Version.created_by', index=17,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='google.appengine.v1alpha.Version.create_time', index=18,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_usage_bytes', full_name='google.appengine.v1alpha.Version.disk_usage_bytes', index=19,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_api_version', full_name='google.appengine.v1alpha.Version.runtime_api_version', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_main_executable_path', full_name='google.appengine.v1alpha.Version.runtime_main_executable_path', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='handlers', full_name='google.appengine.v1alpha.Version.handlers', index=22,
      number=100, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_handlers', full_name='google.appengine.v1alpha.Version.error_handlers', index=23,
      number=101, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='libraries', full_name='google.appengine.v1alpha.Version.libraries', index=24,
      number=102, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='api_config', full_name='google.appengine.v1alpha.Version.api_config', index=25,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env_variables', full_name='google.appengine.v1alpha.Version.env_variables', index=26,
      number=104, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_expiration', full_name='google.appengine.v1alpha.Version.default_expiration', index=27,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_check', full_name='google.appengine.v1alpha.Version.health_check', index=28,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readiness_check', full_name='google.appengine.v1alpha.Version.readiness_check', index=29,
      number=112, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='liveness_check', full_name='google.appengine.v1alpha.Version.liveness_check', index=30,
      number=113, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nobuild_files_regex', full_name='google.appengine.v1alpha.Version.nobuild_files_regex', index=31,
      number=107, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deployment', full_name='google.appengine.v1alpha.Version.deployment', index=32,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_url', full_name='google.appengine.v1alpha.Version.version_url', index=33,
      number=109, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoints_api_service', full_name='google.appengine.v1alpha.Version.endpoints_api_service', index=34,
      number=110, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lifecycle', full_name='google.appengine.v1alpha.Version.lifecycle', index=35,
      number=115, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entrypoint', full_name='google.appengine.v1alpha.Version.entrypoint', index=36,
      number=122, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_stats', full_name='google.appengine.v1alpha.Version.instance_stats', index=37,
      number=300, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vpc_access_connector', full_name='google.appengine.v1alpha.Version.vpc_access_connector', index=38,
      number=121, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_VERSION_BETASETTINGSENTRY, _VERSION_ENVVARIABLESENTRY, ],
  enum_types=[
    _VERSION_LIFECYCLETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='scaling', full_name='google.appengine.v1alpha.Version.scaling',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=280,
  serialized_end=2302,
)


_INSTANCESTATS = _descriptor.Descriptor(
  name='InstanceStats',
  full_name='google.appengine.v1alpha.InstanceStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_instances', full_name='google.appengine.v1alpha.InstanceStats.num_instances', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_healthy_instances', full_name='google.appengine.v1alpha.InstanceStats.num_healthy_instances', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2304,
  serialized_end=2373,
)


_ENDPOINTSAPISERVICE = _descriptor.Descriptor(
  name='EndpointsApiService',
  full_name='google.appengine.v1alpha.EndpointsApiService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.appengine.v1alpha.EndpointsApiService.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_id', full_name='google.appengine.v1alpha.EndpointsApiService.config_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rollout_strategy', full_name='google.appengine.v1alpha.EndpointsApiService.rollout_strategy', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_trace_sampling', full_name='google.appengine.v1alpha.EndpointsApiService.disable_trace_sampling', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ENDPOINTSAPISERVICE_ROLLOUTSTRATEGY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2376,
  serialized_end=2628,
)


_AUTOMATICSCALING = _descriptor.Descriptor(
  name='AutomaticScaling',
  full_name='google.appengine.v1alpha.AutomaticScaling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cool_down_period', full_name='google.appengine.v1alpha.AutomaticScaling.cool_down_period', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_utilization', full_name='google.appengine.v1alpha.AutomaticScaling.cpu_utilization', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_concurrent_requests', full_name='google.appengine.v1alpha.AutomaticScaling.max_concurrent_requests', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_idle_instances', full_name='google.appengine.v1alpha.AutomaticScaling.max_idle_instances', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_total_instances', full_name='google.appengine.v1alpha.AutomaticScaling.max_total_instances', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_pending_latency', full_name='google.appengine.v1alpha.AutomaticScaling.max_pending_latency', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_idle_instances', full_name='google.appengine.v1alpha.AutomaticScaling.min_idle_instances', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_total_instances', full_name='google.appengine.v1alpha.AutomaticScaling.min_total_instances', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_pending_latency', full_name='google.appengine.v1alpha.AutomaticScaling.min_pending_latency', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_utilization', full_name='google.appengine.v1alpha.AutomaticScaling.request_utilization', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_utilization', full_name='google.appengine.v1alpha.AutomaticScaling.disk_utilization', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_utilization', full_name='google.appengine.v1alpha.AutomaticScaling.network_utilization', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_metrics', full_name='google.appengine.v1alpha.AutomaticScaling.custom_metrics', index=12,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='standard_scheduler_settings', full_name='google.appengine.v1alpha.AutomaticScaling.standard_scheduler_settings', index=13,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2631,
  serialized_end=3401,
)


_BASICSCALING = _descriptor.Descriptor(
  name='BasicScaling',
  full_name='google.appengine.v1alpha.BasicScaling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='idle_timeout', full_name='google.appengine.v1alpha.BasicScaling.idle_timeout', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_instances', full_name='google.appengine.v1alpha.BasicScaling.max_instances', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3403,
  serialized_end=3489,
)


_MANUALSCALING = _descriptor.Descriptor(
  name='ManualScaling',
  full_name='google.appengine.v1alpha.ManualScaling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instances', full_name='google.appengine.v1alpha.ManualScaling.instances', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3491,
  serialized_end=3525,
)


_CPUUTILIZATION = _descriptor.Descriptor(
  name='CpuUtilization',
  full_name='google.appengine.v1alpha.CpuUtilization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aggregation_window_length', full_name='google.appengine.v1alpha.CpuUtilization.aggregation_window_length', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_utilization', full_name='google.appengine.v1alpha.CpuUtilization.target_utilization', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3527,
  serialized_end=3633,
)


_REQUESTUTILIZATION = _descriptor.Descriptor(
  name='RequestUtilization',
  full_name='google.appengine.v1alpha.RequestUtilization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_request_count_per_second', full_name='google.appengine.v1alpha.RequestUtilization.target_request_count_per_second', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_concurrent_requests', full_name='google.appengine.v1alpha.RequestUtilization.target_concurrent_requests', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3635,
  serialized_end=3732,
)


_DISKUTILIZATION = _descriptor.Descriptor(
  name='DiskUtilization',
  full_name='google.appengine.v1alpha.DiskUtilization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_write_bytes_per_second', full_name='google.appengine.v1alpha.DiskUtilization.target_write_bytes_per_second', index=0,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_write_ops_per_second', full_name='google.appengine.v1alpha.DiskUtilization.target_write_ops_per_second', index=1,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_read_bytes_per_second', full_name='google.appengine.v1alpha.DiskUtilization.target_read_bytes_per_second', index=2,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_read_ops_per_second', full_name='google.appengine.v1alpha.DiskUtilization.target_read_ops_per_second', index=3,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3735,
  serialized_end=3902,
)


_NETWORKUTILIZATION = _descriptor.Descriptor(
  name='NetworkUtilization',
  full_name='google.appengine.v1alpha.NetworkUtilization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_sent_bytes_per_second', full_name='google.appengine.v1alpha.NetworkUtilization.target_sent_bytes_per_second', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_sent_packets_per_second', full_name='google.appengine.v1alpha.NetworkUtilization.target_sent_packets_per_second', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_received_bytes_per_second', full_name='google.appengine.v1alpha.NetworkUtilization.target_received_bytes_per_second', index=2,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_received_packets_per_second', full_name='google.appengine.v1alpha.NetworkUtilization.target_received_packets_per_second', index=3,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3905,
  serialized_end=4089,
)


_CUSTOMMETRIC = _descriptor.Descriptor(
  name='CustomMetric',
  full_name='google.appengine.v1alpha.CustomMetric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metric_name', full_name='google.appengine.v1alpha.CustomMetric.metric_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_type', full_name='google.appengine.v1alpha.CustomMetric.target_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_utilization', full_name='google.appengine.v1alpha.CustomMetric.target_utilization', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='single_instance_assignment', full_name='google.appengine.v1alpha.CustomMetric.single_instance_assignment', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='google.appengine.v1alpha.CustomMetric.filter', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target_spec', full_name='google.appengine.v1alpha.CustomMetric.target_spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4092,
  serialized_end=4247,
)


_STANDARDSCHEDULERSETTINGS = _descriptor.Descriptor(
  name='StandardSchedulerSettings',
  full_name='google.appengine.v1alpha.StandardSchedulerSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_cpu_utilization', full_name='google.appengine.v1alpha.StandardSchedulerSettings.target_cpu_utilization', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_throughput_utilization', full_name='google.appengine.v1alpha.StandardSchedulerSettings.target_throughput_utilization', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_instances', full_name='google.appengine.v1alpha.StandardSchedulerSettings.min_instances', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_instances', full_name='google.appengine.v1alpha.StandardSchedulerSettings.max_instances', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4250,
  serialized_end=4394,
)


_NETWORK = _descriptor.Descriptor(
  name='Network',
  full_name='google.appengine.v1alpha.Network',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='forwarded_ports', full_name='google.appengine.v1alpha.Network.forwarded_ports', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_tag', full_name='google.appengine.v1alpha.Network.instance_tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.appengine.v1alpha.Network.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnetwork_name', full_name='google.appengine.v1alpha.Network.subnetwork_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_affinity', full_name='google.appengine.v1alpha.Network.session_affinity', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4396,
  serialized_end=4517,
)


_VOLUME = _descriptor.Descriptor(
  name='Volume',
  full_name='google.appengine.v1alpha.Volume',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.appengine.v1alpha.Volume.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume_type', full_name='google.appengine.v1alpha.Volume.volume_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_gb', full_name='google.appengine.v1alpha.Volume.size_gb', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4519,
  serialized_end=4579,
)


_RESOURCES = _descriptor.Descriptor(
  name='Resources',
  full_name='google.appengine.v1alpha.Resources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpu', full_name='google.appengine.v1alpha.Resources.cpu', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_gb', full_name='google.appengine.v1alpha.Resources.disk_gb', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory_gb', full_name='google.appengine.v1alpha.Resources.memory_gb', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumes', full_name='google.appengine.v1alpha.Resources.volumes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4581,
  serialized_end=4692,
)


_VPCACCESSCONNECTOR = _descriptor.Descriptor(
  name='VpcAccessConnector',
  full_name='google.appengine.v1alpha.VpcAccessConnector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.appengine.v1alpha.VpcAccessConnector.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4694,
  serialized_end=4728,
)


_ENTRYPOINT = _descriptor.Descriptor(
  name='Entrypoint',
  full_name='google.appengine.v1alpha.Entrypoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shell', full_name='google.appengine.v1alpha.Entrypoint.shell', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='command', full_name='google.appengine.v1alpha.Entrypoint.command',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4730,
  serialized_end=4770,
)

_VERSION_BETASETTINGSENTRY.containing_type = _VERSION
_VERSION_ENVVARIABLESENTRY.containing_type = _VERSION
_VERSION.fields_by_name['automatic_scaling'].message_type = _AUTOMATICSCALING
_VERSION.fields_by_name['basic_scaling'].message_type = _BASICSCALING
_VERSION.fields_by_name['manual_scaling'].message_type = _MANUALSCALING
_VERSION.fields_by_name['inbound_services'].enum_type = _INBOUNDSERVICETYPE
_VERSION.fields_by_name['network'].message_type = _NETWORK
_VERSION.fields_by_name['resources'].message_type = _RESOURCES
_VERSION.fields_by_name['beta_settings'].message_type = _VERSION_BETASETTINGSENTRY
_VERSION.fields_by_name['serving_status'].enum_type = _SERVINGSTATUS
_VERSION.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_VERSION.fields_by_name['handlers'].message_type = google_dot_cloud_dot_appengine__v1alpha_dot_proto_dot_app__yaml__pb2._URLMAP
_VERSION.fields_by_name['error_handlers'].message_type = google_dot_cloud_dot_appengine__v1alpha_dot_proto_dot_app__yaml__pb2._ERRORHANDLER
_VERSION.fields_by_name['libraries'].message_type = google_dot_cloud_dot_appengine__v1alpha_dot_proto_dot_app__yaml__pb2._LIBRARY
_VERSION.fields_by_name['api_config'].message_type = google_dot_cloud_dot_appengine__v1alpha_dot_proto_dot_app__yaml__pb2._APICONFIGHANDLER
_VERSION.fields_by_name['env_variables'].message_type = _VERSION_ENVVARIABLESENTRY
_VERSION.fields_by_name['default_expiration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_VERSION.fields_by_name['health_check'].message_type = google_dot_cloud_dot_appengine__v1alpha_dot_proto_dot_app__yaml__pb2._HEALTHCHECK
_VERSION.fields_by_name['readiness_check'].message_type = google_dot_cloud_dot_appengine__v1alpha_dot_proto_dot_app__yaml__pb2._READINESSCHECK
_VERSION.fields_by_name['liveness_check'].message_type = google_dot_cloud_dot_appengine__v1alpha_dot_proto_dot_app__yaml__pb2._LIVENESSCHECK
_VERSION.fields_by_name['deployment'].message_type = google_dot_cloud_dot_appengine__v1alpha_dot_proto_dot_deploy__pb2._DEPLOYMENT
_VERSION.fields_by_name['endpoints_api_service'].message_type = _ENDPOINTSAPISERVICE
_VERSION.fields_by_name['lifecycle'].enum_type = _VERSION_LIFECYCLETYPE
_VERSION.fields_by_name['entrypoint'].message_type = _ENTRYPOINT
_VERSION.fields_by_name['instance_stats'].message_type = _INSTANCESTATS
_VERSION.fields_by_name['vpc_access_connector'].message_type = _VPCACCESSCONNECTOR
_VERSION_LIFECYCLETYPE.containing_type = _VERSION
_VERSION.oneofs_by_name['scaling'].fields.append(
  _VERSION.fields_by_name['automatic_scaling'])
_VERSION.fields_by_name['automatic_scaling'].containing_oneof = _VERSION.oneofs_by_name['scaling']
_VERSION.oneofs_by_name['scaling'].fields.append(
  _VERSION.fields_by_name['basic_scaling'])
_VERSION.fields_by_name['basic_scaling'].containing_oneof = _VERSION.oneofs_by_name['scaling']
_VERSION.oneofs_by_name['scaling'].fields.append(
  _VERSION.fields_by_name['manual_scaling'])
_VERSION.fields_by_name['manual_scaling'].containing_oneof = _VERSION.oneofs_by_name['scaling']
_ENDPOINTSAPISERVICE.fields_by_name['rollout_strategy'].enum_type = _ENDPOINTSAPISERVICE_ROLLOUTSTRATEGY
_ENDPOINTSAPISERVICE_ROLLOUTSTRATEGY.containing_type = _ENDPOINTSAPISERVICE
_AUTOMATICSCALING.fields_by_name['cool_down_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_AUTOMATICSCALING.fields_by_name['cpu_utilization'].message_type = _CPUUTILIZATION
_AUTOMATICSCALING.fields_by_name['max_pending_latency'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_AUTOMATICSCALING.fields_by_name['min_pending_latency'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_AUTOMATICSCALING.fields_by_name['request_utilization'].message_type = _REQUESTUTILIZATION
_AUTOMATICSCALING.fields_by_name['disk_utilization'].message_type = _DISKUTILIZATION
_AUTOMATICSCALING.fields_by_name['network_utilization'].message_type = _NETWORKUTILIZATION
_AUTOMATICSCALING.fields_by_name['custom_metrics'].message_type = _CUSTOMMETRIC
_AUTOMATICSCALING.fields_by_name['standard_scheduler_settings'].message_type = _STANDARDSCHEDULERSETTINGS
_BASICSCALING.fields_by_name['idle_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CPUUTILIZATION.fields_by_name['aggregation_window_length'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CUSTOMMETRIC.oneofs_by_name['target_spec'].fields.append(
  _CUSTOMMETRIC.fields_by_name['target_utilization'])
_CUSTOMMETRIC.fields_by_name['target_utilization'].containing_oneof = _CUSTOMMETRIC.oneofs_by_name['target_spec']
_CUSTOMMETRIC.oneofs_by_name['target_spec'].fields.append(
  _CUSTOMMETRIC.fields_by_name['single_instance_assignment'])
_CUSTOMMETRIC.fields_by_name['single_instance_assignment'].containing_oneof = _CUSTOMMETRIC.oneofs_by_name['target_spec']
_RESOURCES.fields_by_name['volumes'].message_type = _VOLUME
_ENTRYPOINT.oneofs_by_name['command'].fields.append(
  _ENTRYPOINT.fields_by_name['shell'])
_ENTRYPOINT.fields_by_name['shell'].containing_oneof = _ENTRYPOINT.oneofs_by_name['command']
DESCRIPTOR.message_types_by_name['Version'] = _VERSION
DESCRIPTOR.message_types_by_name['InstanceStats'] = _INSTANCESTATS
DESCRIPTOR.message_types_by_name['EndpointsApiService'] = _ENDPOINTSAPISERVICE
DESCRIPTOR.message_types_by_name['AutomaticScaling'] = _AUTOMATICSCALING
DESCRIPTOR.message_types_by_name['BasicScaling'] = _BASICSCALING
DESCRIPTOR.message_types_by_name['ManualScaling'] = _MANUALSCALING
DESCRIPTOR.message_types_by_name['CpuUtilization'] = _CPUUTILIZATION
DESCRIPTOR.message_types_by_name['RequestUtilization'] = _REQUESTUTILIZATION
DESCRIPTOR.message_types_by_name['DiskUtilization'] = _DISKUTILIZATION
DESCRIPTOR.message_types_by_name['NetworkUtilization'] = _NETWORKUTILIZATION
DESCRIPTOR.message_types_by_name['CustomMetric'] = _CUSTOMMETRIC
DESCRIPTOR.message_types_by_name['StandardSchedulerSettings'] = _STANDARDSCHEDULERSETTINGS
DESCRIPTOR.message_types_by_name['Network'] = _NETWORK
DESCRIPTOR.message_types_by_name['Volume'] = _VOLUME
DESCRIPTOR.message_types_by_name['Resources'] = _RESOURCES
DESCRIPTOR.message_types_by_name['VpcAccessConnector'] = _VPCACCESSCONNECTOR
DESCRIPTOR.message_types_by_name['Entrypoint'] = _ENTRYPOINT
DESCRIPTOR.enum_types_by_name['InboundServiceType'] = _INBOUNDSERVICETYPE
DESCRIPTOR.enum_types_by_name['ServingStatus'] = _SERVINGSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Version = _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), {

  'BetaSettingsEntry' : _reflection.GeneratedProtocolMessageType('BetaSettingsEntry', (_message.Message,), {
    'DESCRIPTOR' : _VERSION_BETASETTINGSENTRY,
    '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
    # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.Version.BetaSettingsEntry)
    })
  ,

  'EnvVariablesEntry' : _reflection.GeneratedProtocolMessageType('EnvVariablesEntry', (_message.Message,), {
    'DESCRIPTOR' : _VERSION_ENVVARIABLESENTRY,
    '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
    # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.Version.EnvVariablesEntry)
    })
  ,
  'DESCRIPTOR' : _VERSION,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """A Version resource is a specific set of source code and configuration
  files that are deployed into a service.
  
  Attributes:
      name:
          Full path to the Version resource in the API. Example:
          ``apps/myapp/services/default/versions/v1``.  @OutputOnly
      id:
          Relative name of the version within the service. Example:
          ``v1``. Version names can contain only lowercase letters,
          numbers, or hyphens. Reserved names: “default”, “latest”, and
          any name with the prefix “ah-”.
      scaling:
          Controls how instances are created.  Defaults to
          ``AutomaticScaling``.
      automatic_scaling:
          Automatic scaling is based on request rate, response
          latencies, and other application metrics.
      basic_scaling:
          A service with basic scaling will create an instance when the
          application receives a request. The instance will be turned
          down when the app becomes idle. Basic scaling is ideal for
          work that is intermittent or driven by user activity.
      manual_scaling:
          A service with manual scaling runs continuously, allowing you
          to perform complex initialization and rely on the state of its
          memory over time.
      inbound_services:
          Before an application can receive email or XMPP messages, the
          application must be configured to enable the service.
      instance_class:
          Instance class that is used to run this version. Valid values
          are:  -  AutomaticScaling: ``F1``, ``F2``, ``F4``, ``F4_1G`` -
          ManualScaling or BasicScaling: ``B1``, ``B2``, ``B4``, ``B8``,
          ``B4_1G``  Defaults to ``F1`` for AutomaticScaling and ``B1``
          for ManualScaling or BasicScaling.
      network:
          Extra network settings.
      zones:
          The Google Compute Engine zones that are supported by this
          version in the App Engine flexible environment. Deprecated.
      resources:
          Machine resources for this version. Only applicable in the App
          Engine flexible environment.
      runtime:
          Desired runtime. Example: ``python27``.
      runtime_channel:
          The channel of the runtime to use. Only available for some
          runtimes. Defaults to the ``default`` channel.
      threadsafe:
          Whether multiple requests can be dispatched to this version at
          once.
      vm:
          Whether to deploy this version in a container on a virtual
          machine.
      beta_settings:
          Metadata settings that are supplied to this version to enable
          beta runtime features.
      env:
          App Engine execution environment for this version.  Defaults
          to ``standard``.
      serving_status:
          Current serving status of this version. Only the versions with
          a ``SERVING`` status create instances and can be billed.
          ``SERVING_STATUS_UNSPECIFIED`` is an invalid value. Defaults
          to ``SERVING``.
      created_by:
          Email address of the user who created this version.
          @OutputOnly
      create_time:
          Time that this version was created.  @OutputOnly
      disk_usage_bytes:
          Total size in bytes of all the files that are included in this
          version and currently hosted on the App Engine disk.
          @OutputOnly
      runtime_api_version:
          The version of the API in the given runtime environment.
          Please see the app.yaml reference for valid values at https://
          cloud.google.com/appengine/docs/standard//config/appref
      runtime_main_executable_path:
          The path or name of the app’s main executable.
      handlers:
          An ordered list of URL-matching patterns that should be
          applied to incoming requests. The first matching URL handles
          the request and other request handlers are not attempted.
          Only returned in ``GET`` requests if ``view=FULL`` is set.
      error_handlers:
          Custom static error pages. Limited to 10KB per page.  Only
          returned in ``GET`` requests if ``view=FULL`` is set.
      libraries:
          Configuration for third-party Python runtime libraries that
          are required by the application.  Only returned in ``GET``
          requests if ``view=FULL`` is set.
      api_config:
          Serving configuration for `Google Cloud Endpoints <https://clo
          ud.google.com/appengine/docs/python/endpoints/>`__.  Only
          returned in ``GET`` requests if ``view=FULL`` is set.
      env_variables:
          Environment variables available to the application.  Only
          returned in ``GET`` requests if ``view=FULL`` is set.
      default_expiration:
          Duration that static files should be cached by web proxies and
          browsers. Only applicable if the corresponding
          `StaticFilesHandler
          <https://cloud.google.com/appengine/docs/admin-api/reference/r
          est/v1alpha/apps.services.versions#StaticFilesHandler>`__ does
          not specify its own expiration time.  Only returned in ``GET``
          requests if ``view=FULL`` is set.
      health_check:
          Configures health checking for instances. Unhealthy instances
          are stopped and replaced with new instances. Only applicable
          in the App Engine flexible environment.  Only returned in
          ``GET`` requests if ``view=FULL`` is set.
      readiness_check:
          Configures readiness health checking for instances. Unhealthy
          instances are not put into the backend traffic rotation.  Only
          returned in ``GET`` requests if ``view=FULL`` is set.
      liveness_check:
          Configures liveness health checking for instances. Unhealthy
          instances are stopped and replaced with new instances  Only
          returned in ``GET`` requests if ``view=FULL`` is set.
      nobuild_files_regex:
          Files that match this pattern will not be built into this
          version. Only applicable for Go runtimes.  Only returned in
          ``GET`` requests if ``view=FULL`` is set.
      deployment:
          Code and application artifacts that make up this version.
          Only returned in ``GET`` requests if ``view=FULL`` is set.
      version_url:
          Serving URL for this version. Example: “https://myversion-dot-
          myservice-dot-myapp.appspot.com”  @OutputOnly
      endpoints_api_service:
          Cloud Endpoints configuration.  If endpoints_api_service is
          set, the Cloud Endpoints Extensible Service Proxy will be
          provided to serve the API implemented by the app.
      lifecycle:
          The type of lifecycle for this version.
      entrypoint:
          The entrypoint for the application.
      instance_stats:
          Instance statistics. @OutputOnly
      vpc_access_connector:
          Enables VPC connectivity for standard apps.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.Version)
  })
_sym_db.RegisterMessage(Version)
_sym_db.RegisterMessage(Version.BetaSettingsEntry)
_sym_db.RegisterMessage(Version.EnvVariablesEntry)

InstanceStats = _reflection.GeneratedProtocolMessageType('InstanceStats', (_message.Message,), {
  'DESCRIPTOR' : _INSTANCESTATS,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """Statistics on the number of instances.
  
  Attributes:
      num_instances:
          The current number of instances running for this version.
      num_healthy_instances:
          The current number of healthy instances running for this
          version.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.InstanceStats)
  })
_sym_db.RegisterMessage(InstanceStats)

EndpointsApiService = _reflection.GeneratedProtocolMessageType('EndpointsApiService', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTSAPISERVICE,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """\ `Cloud Endpoints <https://cloud.google.com/endpoints>`__
  configuration. The Endpoints API Service provides tooling for serving
  Open API and gRPC endpoints via an NGINX proxy. Only valid for App
  Engine Flexible environment deployments.  The fields here refer to the
  name and configuration ID of a “service” resource in the `Service
  Management API <https://cloud.google.com/service-
  management/overview>`__.
  
  Attributes:
      name:
          Endpoints service name which is the name of the “service”
          resource in the Service Management API. For example
          “myapi.endpoints.myproject.cloud.goog”
      config_id:
          Endpoints service configuration ID as specified by the Service
          Management API. For example “2016-09-19r1”.  By default, the
          rollout strategy for Endpoints is ``RolloutStrategy.FIXED``.
          This means that Endpoints starts up with a particular
          configuration ID. When a new configuration is rolled out,
          Endpoints must be given the new configuration ID. The
          ``config_id`` field is used to give the configuration ID and
          is required in this case.  Endpoints also has a rollout
          strategy called ``RolloutStrategy.MANAGED``. When using this,
          Endpoints fetches the latest configuration and does not need
          the configuration ID. In this case, ``config_id`` must be
          omitted.
      rollout_strategy:
          Endpoints rollout strategy. If ``FIXED``, ``config_id`` must
          be specified. If ``MANAGED``, ``config_id`` must be omitted.
      disable_trace_sampling:
          Enable or disable trace sampling. By default, this is set to
          false for enabled.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.EndpointsApiService)
  })
_sym_db.RegisterMessage(EndpointsApiService)

AutomaticScaling = _reflection.GeneratedProtocolMessageType('AutomaticScaling', (_message.Message,), {
  'DESCRIPTOR' : _AUTOMATICSCALING,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """Automatic scaling is based on request rate, response latencies, and
  other application metrics.
  
  Attributes:
      cool_down_period:
          The time period that the `Autoscaler
          <https://cloud.google.com/compute/docs/autoscaler/>`__ should
          wait before it starts collecting information from a new
          instance. This prevents the autoscaler from collecting
          information when the instance is initializing, during which
          the collected usage would not be reliable. Only applicable in
          the App Engine flexible environment.
      cpu_utilization:
          Target scaling by CPU usage.
      max_concurrent_requests:
          Number of concurrent requests an automatic scaling instance
          can accept before the scheduler spawns a new instance.
          Defaults to a runtime-specific value.
      max_idle_instances:
          Maximum number of idle instances that should be maintained for
          this version.
      max_total_instances:
          Maximum number of instances that should be started to handle
          requests for this version.
      max_pending_latency:
          Maximum amount of time that a request should wait in the
          pending queue before starting a new instance to handle it.
      min_idle_instances:
          Minimum number of idle instances that should be maintained for
          this version. Only applicable for the default version of a
          service.
      min_total_instances:
          Minimum number of running instances that should be maintained
          for this version.
      min_pending_latency:
          Minimum amount of time a request should wait in the pending
          queue before starting a new instance to handle it.
      request_utilization:
          Target scaling by request utilization.
      disk_utilization:
          Target scaling by disk usage.
      network_utilization:
          Target scaling by network usage.
      custom_metrics:
          Target scaling by user-provided metrics. Only applicable in
          the App Engine flexible environment.
      standard_scheduler_settings:
          Scheduler settings for standard environment.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.AutomaticScaling)
  })
_sym_db.RegisterMessage(AutomaticScaling)

BasicScaling = _reflection.GeneratedProtocolMessageType('BasicScaling', (_message.Message,), {
  'DESCRIPTOR' : _BASICSCALING,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """A service with basic scaling will create an instance when the
  application receives a request. The instance will be turned down when
  the app becomes idle. Basic scaling is ideal for work that is
  intermittent or driven by user activity.
  
  Attributes:
      idle_timeout:
          Duration of time after the last request that an instance must
          wait before the instance is shut down.
      max_instances:
          Maximum number of instances to create for this version.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.BasicScaling)
  })
_sym_db.RegisterMessage(BasicScaling)

ManualScaling = _reflection.GeneratedProtocolMessageType('ManualScaling', (_message.Message,), {
  'DESCRIPTOR' : _MANUALSCALING,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """A service with manual scaling runs continuously, allowing you to
  perform complex initialization and rely on the state of its memory
  over time.
  
  Attributes:
      instances:
          Number of instances to assign to the service at the start.
          This number can later be altered by using the `Modules API <ht
          tps://cloud.google.com/appengine/docs/python/modules/functions
          >`__ ``set_num_instances()`` function.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.ManualScaling)
  })
_sym_db.RegisterMessage(ManualScaling)

CpuUtilization = _reflection.GeneratedProtocolMessageType('CpuUtilization', (_message.Message,), {
  'DESCRIPTOR' : _CPUUTILIZATION,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """Target scaling by CPU usage.
  
  Attributes:
      aggregation_window_length:
          Period of time over which CPU utilization is calculated.
      target_utilization:
          Target CPU utilization ratio to maintain when scaling. Must be
          between 0 and 1.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.CpuUtilization)
  })
_sym_db.RegisterMessage(CpuUtilization)

RequestUtilization = _reflection.GeneratedProtocolMessageType('RequestUtilization', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTUTILIZATION,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """Target scaling by request utilization. Only applicable in the App
  Engine flexible environment.
  
  Attributes:
      target_request_count_per_second:
          Target requests per second.
      target_concurrent_requests:
          Target number of concurrent requests.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.RequestUtilization)
  })
_sym_db.RegisterMessage(RequestUtilization)

DiskUtilization = _reflection.GeneratedProtocolMessageType('DiskUtilization', (_message.Message,), {
  'DESCRIPTOR' : _DISKUTILIZATION,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """Target scaling by disk usage. Only applicable in the App Engine
  flexible environment.
  
  Attributes:
      target_write_bytes_per_second:
          Target bytes written per second.
      target_write_ops_per_second:
          Target ops written per second.
      target_read_bytes_per_second:
          Target bytes read per second.
      target_read_ops_per_second:
          Target ops read per seconds.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.DiskUtilization)
  })
_sym_db.RegisterMessage(DiskUtilization)

NetworkUtilization = _reflection.GeneratedProtocolMessageType('NetworkUtilization', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKUTILIZATION,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """Target scaling by network usage. Only applicable in the App Engine
  flexible environment.
  
  Attributes:
      target_sent_bytes_per_second:
          Target bytes sent per second.
      target_sent_packets_per_second:
          Target packets sent per second.
      target_received_bytes_per_second:
          Target bytes received per second.
      target_received_packets_per_second:
          Target packets received per second.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.NetworkUtilization)
  })
_sym_db.RegisterMessage(NetworkUtilization)

CustomMetric = _reflection.GeneratedProtocolMessageType('CustomMetric', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMMETRIC,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """Allows autoscaling based on Stackdriver metrics.
  
  Attributes:
      metric_name:
          The name of the metric.
      target_type:
          The type of the metric. Must be a string representing a
          Stackdriver metric type e.g. GAGUE, DELTA_PER_SECOND, etc.
      target_spec:
          The target spec.
      target_utilization:
          The target value for the metric.
      single_instance_assignment:
          May be used instead of ``target_utilization`` when an instance
          can handle a specific amount of work/resources and the metric
          value is equal to the current amount of work remaining. The
          autoscaler will try to keep the number of instances equal to
          the metric value divided by ``single_instance_assignment``.
      filter:
          Allows filtering on the metric’s fields.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.CustomMetric)
  })
_sym_db.RegisterMessage(CustomMetric)

StandardSchedulerSettings = _reflection.GeneratedProtocolMessageType('StandardSchedulerSettings', (_message.Message,), {
  'DESCRIPTOR' : _STANDARDSCHEDULERSETTINGS,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """Scheduler settings for standard environment.
  
  Attributes:
      target_cpu_utilization:
          Target CPU utilization ratio to maintain when scaling.
      target_throughput_utilization:
          Target throughput utilization ratio to maintain when scaling
      min_instances:
          Minimum number of instances to run for this version. Set to
          zero to disable ``min_instances`` configuration.
      max_instances:
          Maximum number of instances to run for this version. Set to
          zero to disable ``max_instances`` configuration.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.StandardSchedulerSettings)
  })
_sym_db.RegisterMessage(StandardSchedulerSettings)

Network = _reflection.GeneratedProtocolMessageType('Network', (_message.Message,), {
  'DESCRIPTOR' : _NETWORK,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """Extra network settings.
  
  Attributes:
      forwarded_ports:
          List of ports, or port pairs, to forward from the virtual
          machine to the application container. Only applicable in the
          App Engine flexible environment.
      instance_tag:
          Tag to apply to the instance during creation. Only applicable
          in the App Engine flexible environment.
      name:
          The Google Compute Engine network that this resource is
          currently attached to. Either the relative path of the network
          resource, or the short name of the network must be specified.
          If the network belongs to another project, the path of the
          resource must be specified. e.g.,
          ``projects/{project}/global/networks/{network}`` or ``my-
          network``.  See `the VPC documentation
          <https://cloud.google.com/compute/docs/vpc>`__ for more
          information about connecting GCP projects.
      subnetwork_name:
          Google Cloud Platform sub-network where the virtual machines
          are created. Specify the short name, not the resource path.
          If a subnetwork name is specified, a network name will also be
          required unless it is for the default network.  -  If the
          network that the instance is being created in is a Legacy
          network, then the IP address is allocated from the IPv4Range.
          -  If the network that the instance is being created in is an
          auto    Subnet Mode Network, then only network name should be
          specified (not    the subnetwork_name) and the IP address is
          created from the    IPCidrRange of the subnetwork that exists
          in that zone for that    network. -  If the network that the
          instance is being created in is a custom    Subnet Mode
          Network, then the subnetwork_name must be specified and    the
          IP address is created from the IPCidrRange of the subnetwork.
          If specified, the subnetwork must exist in the same region as
          the App Engine flexible environment application.
      session_affinity:
          Enable session affinity. Only applicable in the App Engine
          flexible environment.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.Network)
  })
_sym_db.RegisterMessage(Network)

Volume = _reflection.GeneratedProtocolMessageType('Volume', (_message.Message,), {
  'DESCRIPTOR' : _VOLUME,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """Volumes mounted within the app container. Only applicable in the App
  Engine flexible environment.
  
  Attributes:
      name:
          Unique name for the volume.
      volume_type:
          Underlying volume type, e.g. ‘tmpfs’.
      size_gb:
          Volume size in gigabytes.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.Volume)
  })
_sym_db.RegisterMessage(Volume)

Resources = _reflection.GeneratedProtocolMessageType('Resources', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCES,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """Machine resources for a version.
  
  Attributes:
      cpu:
          Number of CPU cores needed.
      disk_gb:
          Disk size (GB) needed.
      memory_gb:
          Memory (GB) needed.
      volumes:
          User specified volumes.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.Resources)
  })
_sym_db.RegisterMessage(Resources)

VpcAccessConnector = _reflection.GeneratedProtocolMessageType('VpcAccessConnector', (_message.Message,), {
  'DESCRIPTOR' : _VPCACCESSCONNECTOR,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """VPC access connector specification.
  
  Attributes:
      name:
          Full Serverless VPC Access Connector name e.g. /projects/my-
          project/locations/us-central1/connectors/c1.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.VpcAccessConnector)
  })
_sym_db.RegisterMessage(VpcAccessConnector)

Entrypoint = _reflection.GeneratedProtocolMessageType('Entrypoint', (_message.Message,), {
  'DESCRIPTOR' : _ENTRYPOINT,
  '__module__' : 'google.cloud.appengine_v1alpha.proto.version_pb2'
  ,
  '__doc__': """The entrypoint for the application.
  
  Attributes:
      command:
          The command to run.
      shell:
          The format should be a shell command that can be fed to ``bash
          -c``.
  """,
  # @@protoc_insertion_point(class_scope:google.appengine.v1alpha.Entrypoint)
  })
_sym_db.RegisterMessage(Entrypoint)


DESCRIPTOR._options = None
_VERSION_BETASETTINGSENTRY._options = None
_VERSION_ENVVARIABLESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*- #
# Copyright 2022 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Vertex AI deployment resource pools list command."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.ai.deployment_resource_pools import client
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.ai import constants
from googlecloudsdk.command_lib.ai import endpoint_util
from googlecloudsdk.command_lib.ai import flags
from googlecloudsdk.command_lib.ai import region_util
from googlecloudsdk.core import resources

_DEFAULT_FORMAT = """
        table(
            name.basename():label=DEPLOYMENT_RESOURCE_POOL_ID
        )
    """


def _GetUri(deployment_resource_pool):
  ref = resources.REGISTRY.ParseRelativeName(
      deployment_resource_pool.name,
      constants.DEPLOYMENT_RESOURCE_POOLS_COLLECTION)
  return ref.SelfLink()


def _AddArgsBeta(parser):
  """Adding deployment resource pool arguments from CLI.

  Args:
    parser: argparse.ArgumentParser, cli argument parser

  Returns:
    None
  """
  parser.display_info.AddFormat(_DEFAULT_FORMAT)
  parser.display_info.AddUriFunc(_GetUri)
  flags.AddRegionResourceArg(
      parser,
      'to list deployment resource pools',
      prompt_func=region_util.PromptForDeploymentResourcePoolSupportedRegion)


def _RunBeta(args):
  """List Vertex AI deployment resource pools."""
  version = constants.BETA_VERSION
  region_ref = args.CONCEPTS.region.Parse()
  args.region = region_ref.AsDict()['locationsId']
  with endpoint_util.AiplatformEndpointOverrides(version, region=args.region):
    return client.DeploymentResourcePoolsClient(
        version=version).ListBeta(region_ref)


@base.Hidden
@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
class ListV1Beta1(base.ListCommand):
  """List existing Vertex AI deployment resource pools.

  ## EXAMPLES

  To list the deployment resource pools under project ``example'' in region
  ``us-central1'', run:

    $ {command} --project=example --region=us-central1
  """

  @staticmethod
  def Args(parser):
    return _AddArgsBeta(parser)

  def Run(self, args):
    return _RunBeta(args)



# -*- coding: utf-8 -*- #
# Copyright 2014 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command for creating URL maps."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.compute import base_classes
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.compute import flags as compute_flags
from googlecloudsdk.command_lib.compute import scope as compute_scope
from googlecloudsdk.command_lib.compute.backend_buckets import flags as backend_bucket_flags
from googlecloudsdk.command_lib.compute.backend_services import flags as backend_service_flags
from googlecloudsdk.command_lib.compute.url_maps import flags
from googlecloudsdk.command_lib.compute.url_maps import url_maps_utils


def _DetailedHelp():
  return {
      'brief':
          'Create a URL map.',
      'DESCRIPTION':
          """
      *{command}* is used to create URL maps which map HTTP and
      HTTPS request URLs to backend services and backend buckets.
      Mappings are done using a longest-match strategy.

      There are two components to a mapping: a host rule and a path
      matcher. A host rule maps one or more hosts to a path
      matcher. A path matcher maps request paths to backend
      services or backend buckets. For example, a host rule can map
      the hosts ``*.google.com'' and ``google.com'' to a path
      matcher called ``www''. The ``www'' path matcher in turn can
      map the path ``/search/*'' to the search backend service, the
      path ``/static/*'' to the static backend bucket  and everything
      else to a default backend service or default backend bucket.

      Host rules and patch matchers can be added to the URL map
      after the map is created by using `gcloud compute url-maps edit`
      or by using `gcloud compute url-maps add-path-matcher`
      and `gcloud compute url-maps add-host-rule`.
      """,
      'EXAMPLES':
          """
        To create a global URL map with a default service, run:

        $ {command} URL_MAP_NAME --default-service=BACKEND_SERVICE_NAME

        To create a regional URL map with a default service, run:

        $ {command} URL_MAP_NAME --default-service=BACKEND_SERVICE_NAME --region=REGION_NAME

        To create a global URL map with a default backend bucket, run:

        $ {command} URL_MAP_NAME --default-backend-bucket=BACKEND_BUCKET_NAME
      """,
  }


def _Args(parser):
  """Common arguments to create commands for each release track."""
  parser.add_argument(
      '--description', help='An optional, textual description for the URL map.')

  group = parser.add_mutually_exclusive_group(required=True)
  group.add_argument(
      '--default-service',
      help=('A backend service that will be used for requests for which this '
            'URL map has no mappings. Exactly one of --default-service or '
            '--default-backend-bucket is required.'))
  group.add_argument(
      '--default-backend-bucket',
      help=('A backend bucket that will be used for requests for which this '
            'URL map has no mappings. Exactly one of --default-service or '
            '--default-backend-bucket is required.'))
  parser.display_info.AddCacheUpdater(flags.UrlMapsCompleter)


def _MakeGlobalRequest(args, url_map_ref, default_backend_uri, client):
  request = client.messages.ComputeUrlMapsInsertRequest(
      project=url_map_ref.project,
      urlMap=client.messages.UrlMap(
          defaultService=default_backend_uri,
          description=args.description,
          name=url_map_ref.Name()))
  return client.MakeRequests([(client.apitools_client.urlMaps, 'Insert',
                               request)])


def _MakeRegionalRequest(args, url_map_ref, default_backend_uri, client):
  request = client.messages.ComputeRegionUrlMapsInsertRequest(
      project=url_map_ref.project,
      urlMap=client.messages.UrlMap(
          defaultService=default_backend_uri,
          description=args.description,
          name=url_map_ref.Name()),
      region=url_map_ref.region)
  return client.MakeRequests([(client.apitools_client.regionUrlMaps, 'Insert',
                               request)])


def _Run(args, holder, backend_bucket_arg, backend_service_arg, url_map_arg):
  """Issues requests necessary to create a Url Map."""
  client = holder.client

  url_map_ref = url_map_arg.ResolveAsResource(
      args,
      holder.resources,
      default_scope=compute_scope.ScopeEnum.GLOBAL,
      scope_lister=compute_flags.GetDefaultScopeLister(client))

  if args.default_service:
    default_backend_uri = url_maps_utils.ResolveUrlMapDefaultService(
        args, backend_service_arg, url_map_ref, holder.resources).SelfLink()
  else:
    default_backend_uri = backend_bucket_arg.ResolveAsResource(
        args, holder.resources).SelfLink()

  if url_maps_utils.IsGlobalUrlMapRef(url_map_ref):
    return _MakeGlobalRequest(args, url_map_ref, default_backend_uri, client)
  elif url_maps_utils.IsRegionalUrlMapRef(url_map_ref):
    return _MakeRegionalRequest(args, url_map_ref, default_backend_uri, client)


@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA,
                    base.ReleaseTrack.GA)
class Create(base.CreateCommand):
  """Create a URL map."""

  detailed_help = _DetailedHelp()
  BACKEND_BUCKET_ARG = None
  BACKEND_SERVICE_ARG = None
  URL_MAP_ARG = None

  @classmethod
  def Args(cls, parser):
    parser.display_info.AddFormat(flags.DEFAULT_LIST_FORMAT)
    cls.BACKEND_BUCKET_ARG = (
        backend_bucket_flags.BackendBucketArgumentForUrlMap(required=False))
    cls.BACKEND_SERVICE_ARG = (
        backend_service_flags.BackendServiceArgumentForUrlMap(required=False))
    cls.URL_MAP_ARG = flags.UrlMapArgument()
    cls.URL_MAP_ARG.AddArgument(parser, operation_type='create')
    _Args(parser)

  def Run(self, args):
    holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
    return _Run(args, holder, self.BACKEND_BUCKET_ARG, self.BACKEND_SERVICE_ARG,
                self.URL_MAP_ARG)
